==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/TodayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TodayExpressionDescription } from "./TodayExpressionDescription";
/**
 * @hidden
 */
export let TodayExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class TodayExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (TodayExpressionDescriptionMetadata.a == null) {
                TodayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TodayExpressionDescriptionMetadata.c(TodayExpressionDescriptionMetadata.a);
            }
            if (a.j(TodayExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(TodayExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            TodayExpressionDescriptionMetadata.b(a);
            a.aa("TodayExpression", () => new TodayExpressionDescription());
            a.z("TodayExpression", TodayExpressionDescriptionMetadata.a);
        }
    }
    TodayExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(TodayExpressionDescriptionMetadata, 'TodayExpressionDescriptionMetadata');
    TodayExpressionDescriptionMetadata.a = null;
    return TodayExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TodayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TodayExpressionDescription } from "./TodayExpressionDescription";
/**
 * @hidden
 */
export let TodayExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class TodayExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (TodayExpressionDescriptionMetadata.a == null) {
                TodayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TodayExpressionDescriptionMetadata.c(TodayExpressionDescriptionMetadata.a);
            }
            if (a.k(TodayExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(TodayExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            TodayExpressionDescriptionMetadata.b(a);
            a.ac("TodayExpression", () => new TodayExpressionDescription());
            a.ab("TodayExpression", TodayExpressionDescriptionMetadata.a);
        }
    }
    TodayExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(TodayExpressionDescriptionMetadata, 'TodayExpressionDescriptionMetadata');
    TodayExpressionDescriptionMetadata.a = null;
    return TodayExpressionDescriptionMetadata;
})();
